@@ -1,6 +1,6 @@
 package Poet::Cache;
 BEGIN {
-  $Poet::Cache::VERSION = '0.12';
+  $Poet::Cache::VERSION = '0.13';
 }    ## no critic (Moose::RequireMakeImmutable)
 use Poet qw($conf $poet);
 use Method::Signatures::Simple;
@@ -10,8 +10,7 @@ extends 'CHI';
 
 method initialize_caching () {
     my $default_config =
-      { defaults => { driver => 'File', root_dir => $poet->data_path("cache") }
-      };
+      { defaults => { driver => 'File', root_dir => $poet->data_path("cache") } };
     my $config = $conf->get_hash( 'cache' => $default_config );
     __PACKAGE__->config($config);
 }
