@@ -2,7 +2,7 @@
 #
 package Poet::Tools;
 BEGIN {
-  $Poet::Tools::VERSION = '0.12';
+  $Poet::Tools::VERSION = '0.13';
 }
 use Carp;
 use Class::MOP;
@@ -157,8 +157,7 @@ sub write_file {
     #
     {
         my $write_fh;
-        unless ( sysopen( $write_fh, $file, $Store_Flags, $file_create_mode ) )
-        {
+        unless ( sysopen( $write_fh, $file, $Store_Flags, $file_create_mode ) ) {
             croak "write_file '$file' - sysopen: $!";
         }
         my $size_left = length($data);
