@@ -1,6 +1,6 @@
 package Poet::t::PSGIHandler;
 BEGIN {
-  $Poet::t::PSGIHandler::VERSION = '0.12';
+  $Poet::t::PSGIHandler::VERSION = '0.13';
 }
 use Test::Class::Most parent => 'Poet::Test::Class';
 use Capture::Tiny qw();
@@ -15,10 +15,7 @@ my $poet = __PACKAGE__->initialize_temp_env(
     }
 );
 unlink( glob( $poet->comps_path("*.mc") ) );
-write_file(
-    $poet->lib_path("TestApp/Foo.pm"),
-    "package TestApp::Foo;\nsub bar {}\n1;\n"
-);
+write_file( $poet->lib_path("TestApp/Foo.pm"), "package TestApp::Foo;\nsub bar {}\n1;\n" );
 
 sub mech {
     my $self = shift;
@@ -41,8 +38,7 @@ sub try_psgi_comp {
     my $path = $params{path} or die "must pass path";
     ( my $uri = $path ) =~ s/\.mc$//;
     my $qs = $params{qs} || '';
-    my $expect_code =
-      defined( $params{expect_code} ) ? $params{expect_code} : 200;
+    my $expect_code = defined( $params{expect_code} ) ? $params{expect_code} : 200;
 
     $self->add_comp(%params);
 
@@ -61,17 +57,12 @@ sub try_psgi_comp {
             $mech->content_like( $expect_content, "$path - content" );
         }
         else {
-            is(
-                trim( $mech->content ),
-                trim($expect_content),
-                "$path - content"
-            );
+            is( trim( $mech->content ), trim($expect_content), "$path - content" );
         }
         is( $mech->status, $expect_code, "$path - code" );
         if ( my $expect_headers = $params{expect_headers} ) {
             while ( my ( $hdr, $value ) = each(%$expect_headers) ) {
-                cmp_deeply( $mech->res->header($hdr),
-                    $value, "$path - header $hdr" );
+                cmp_deeply( $mech->res->header($hdr), $value, "$path - header $hdr" );
             }
         }
     }
@@ -103,7 +94,7 @@ sub test_error : Tests {
         path           => '/error.mc',
         src            => '% die "bleah";',
         expect_code    => 500,
-        expect_content => qr/bleah at/,
+        expect_content => qr/bleah/,
     );
 }
 
@@ -111,8 +102,8 @@ sub test_not_found : Tests {
     my $self = shift;
     my $mech = $self->mech();
     $mech->get("/does/not/exist");
-    is( $mech->status,  404, "status 404" );
-    is( $mech->content, '',  "blank content" );
+    is( $mech->status, 404, "status 404" );
+    like( $mech->content, qr/Not found/, "default not found page" );
 }
 
 sub test_args : Tests {
@@ -160,7 +151,28 @@ will also not be printed
         expect_code    => 302,
         expect_headers => { Location => 'http://www.google.com/' },
     );
-    return;
+    $self->try_psgi_comp(
+        path => '/go_to_redirect.mc',
+        src  => '
+<%init>
+$m->go("/redirect");
+</%init>
+',
+        expect_content => ' ',
+        expect_code    => 302,
+        expect_headers => { Location => 'http://www.google.com/' },
+    );
+    $self->try_psgi_comp(
+        path => '/visit_redirect.mc',
+        src  => '
+<%init>
+$m->visit("/redirect");
+</%init>
+',
+        expect_content => ' ',
+        expect_code    => 302,
+        expect_headers => { Location => 'http://www.google.com/' },
+    );
     $self->try_psgi_comp(
         path => '/redirect_301.mc',
         src  => '
@@ -177,7 +189,7 @@ will not be printed
 will not be printed
 % $m->clear_and_abort(404);
 ',
-        expect_content => ' ',
+        expect_content => qr/Not found/,
         expect_code    => 404,
     );
 }
@@ -261,9 +273,8 @@ root_dir: $expected_root_dir
 sub test_misc : Tests {
     my $self = shift;
     $self->try_psgi_comp(
-        path => '/misc.mc',
-        src =>
-          'TestApp::Foo = <% TestApp::Foo->can("bar") ? "loaded" : "not loaded" %>',
+        path           => '/misc.mc',
+        src            => 'TestApp::Foo = <% TestApp::Foo->can("bar") ? "loaded" : "not loaded" %>',
         expect_content => 'TestApp::Foo = loaded',
     );
 }
